==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/hole/dialogs_en.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")

dialogId("m-nedame1", "font_small",
         "You can't be indian because you are not red?")

dialogId("v-nedame1", "font_big", "I can't demur anything.")

dialogId("v-neber", "font_big",
"Player, if you are an indian, don't perceive as an discrimination please.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")

dialogId("v-zkus", "font_big", "Try it.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/hole/dialogs_en.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")

dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")

dialogId("v-zkus", "font_big", "Try it.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
